==> haskell-hlint-1.9.41-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 1.9.41
id: hlint-1.9.41-DrQziYg9RV2HODep7l1sQ
key: hlint-1.9.41-DrQziYg9RV2HODep7l1sQ
license: BSD3
copyright: Neil Mitchell 2006-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint2
    Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact Config.Haskell Config.Type HSE.All
                HSE.Bracket HSE.FreeVars HSE.Match HSE.Reduce HSE.Scope HSE.Type
                HSE.Util Hint.All Hint.Bracket Hint.Comment Hint.Duplicate
                Hint.Extensions Hint.Import Hint.Lambda Hint.List Hint.ListRec
                Hint.Match Hint.Monad Hint.Naming Hint.NewType Hint.Pattern
                Hint.Pragma Hint.Type Hint.Unsafe Hint.Util Test.All
                Test.Annotations Test.InputOutput Test.Proof Test.Translate
                Test.Util
abi: 7642e01d790b2788f7767a604339925c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hlint-1.9.41
library-dirs: /usr/lib/ghc-8.0.1/site-local/hlint-1.9.41
data-dir: /usr/share/hlint
hs-libraries: HShlint-1.9.41-DrQziYg9RV2HODep7l1sQ
depends:
    ansi-terminal-0.6.2.3-AKTYR0nthhUCHW4HMZvJFX base-4.9.0.0
    cmdargs-0.10.15-BgqoY5S3enuCldigbbRRIV containers-0.5.7.1
    cpphs-1.20.4-LO4krdoPFZv9dMR7FlkcwT directory-1.2.6.2
    extra-1.5.1-HeeVckCVl1V9DE6lYqg83I filepath-1.4.1.0
    haskell-src-exts-1.18.2-7JYrbgADd3D34kjxtkSbG9
    hscolour-1.24.1-H2EUF2muHY0JRKOYWigHLc process-1.4.2.0
    refact-0.3.0.2-JBbxaqExt5tJMSfYCjPwkx transformers-0.5.2.0
    uniplate-1.6.12-3VwHJoF30p3s45WrrHev
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hlint-1.9.41-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hlint
version: 1.9.41
id: hlint-1.9.41-HBcsScTizwhGFuSoasdklT
key: hlint-1.9.41-HBcsScTizwhGFuSoasdklT
license: BSD3
copyright: Neil Mitchell 2006-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/hlint#readme
synopsis: Source code suggestions
description:
    HLint gives suggestions on how to improve your source code.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Language.Haskell.HLint Language.Haskell.HLint2
    Language.Haskell.HLint3
hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                Report Util Parallel Refact Config.Haskell Config.Type HSE.All
                HSE.Bracket HSE.FreeVars HSE.Match HSE.Reduce HSE.Scope HSE.Type
                HSE.Util Hint.All Hint.Bracket Hint.Comment Hint.Duplicate
                Hint.Extensions Hint.Import Hint.Lambda Hint.List Hint.ListRec
                Hint.Match Hint.Monad Hint.Naming Hint.NewType Hint.Pattern
                Hint.Pragma Hint.Type Hint.Unsafe Hint.Util Test.All
                Test.Annotations Test.InputOutput Test.Proof Test.Translate
                Test.Util
abi: c2a9fd5c50fd3a4b8e7b834b367b4e1a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hlint-1.9.41
library-dirs: /usr/lib/ghc-8.0.1/site-local/hlint-1.9.41
data-dir: /usr/share/hlint
hs-libraries: HShlint-1.9.41-HBcsScTizwhGFuSoasdklT
depends:
    ansi-terminal-0.6.2.3-AKTYR0nthhUCHW4HMZvJFX base-4.9.0.0
    cmdargs-0.10.17-Hs2S0uL9DmQG8vy4Sf8xLT containers-0.5.7.1
    cpphs-1.20.5-9m6GAL7GOtv4Rbh8XXGVgk directory-1.2.6.2
    extra-1.5.2-FWjov7JFxoq2wD5IPaMEgG filepath-1.4.1.0
    haskell-src-exts-1.18.2-HHC3x3A3NPPIRZVmSBLAjX
    hscolour-1.24.1-H2EUF2muHY0JRKOYWigHLc process-1.4.2.0
    refact-0.3.0.2-JBbxaqExt5tJMSfYCjPwkx transformers-0.5.2.0
    uniplate-1.6.12-GeJZUKnYhe2EvTBj9Ni0S0
haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
haddock-html: /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
